@@ -1,9 +1,11 @@
 from pathlib import Path
 import typing as t
-from joblib import load,dump
+import pickle
 import pandas as pd
 from sklearn.pipeline import Pipeline
-from prediction_model.core import config,DATASET_DIR,TRAINED_MODEL_DIR
+from prediction_model.core import config,DATASET_DIR,TRAINED_MODEL_DIR,PACKAGE_ROOT
+import sys
+sys.path.append(f'{PACKAGE_ROOT}/')
 from prediction_model import __version__ as _version #could change
 
 #_version = 2.0
@@ -23,12 +25,12 @@ def remove_old_pipeline(*, files_to_keep: t.List[str]) -> None:
         if model_file not in do_not_delete:
             model_file.unlink()
 
-def save_pipeline(*,pipeline_to_persist: Pipeline) -> None:
+def save_pipeline(*,pipeline_to_persist: str) -> None:
     save_file_name = f'{config.pipeline_save_file}{_version}.pkl'
     save_path = Path(TRAINED_MODEL_DIR) / save_file_name
     remove_old_pipeline(files_to_keep = [save_file_name])
-    dump(pipeline_to_persist, save_path)
+    pickle.dump(pipeline_to_persist,open(save_path,'wb'))
 
 def load_pipeline(*,file_name: str) -> Pipeline:
     load_path = Path(TRAINED_MODEL_DIR) / file_name
-    return load(filename=load_path)
\ No newline at end of file
+    return pickle.load(open(load_path,'rb'))
