@@ -1,8 +1,6 @@
-from strictyaml.parser import load
 from prediction_model.validation import validate_inputs
 from prediction_model.core import config
 from prediction_model.data_manager import load_pipeline
-import prediction_model.features
 import typing as t
 import pandas as pd
 from .__init__ import __version__ as _version 
